pro mk_fem_aoslos, year, week, aoslos_file=aoslos_file, interval=interval, asca=asca
;
;+
;NAME:
;	mk_fem_aoslos
;PURPOSE:
;	Generate a AOSLOS file to be used by MK_FEM
;INPUT:
;	week
;	year
;OPTIONAL INPUT:
;	interval - the resolution of the output file in sec.  If
;		not passed it is 15 seconds.
;OUTPUT:
;	aoslos_file-filename of AOSLOS output
;HISTORY:
;	Written 19-Feb-92 by M.Morrison
;	15-Mar-93 (MDM) - Added print statement
;	 7-Apr-93 (MDM) - Added /ASCA option
;-
;
if (n_elements(interval) eq 0) then interval = 15
;
tarr = week2ex(year, week)
ex2int, tarr, time, day
day = day - 1				;back up one day and start at 23:58 hours because of special case
					;where day starts at 00:00:00 exactly - have to see that transition
int2ex, time, day, tarr
;
num = ((24*7+2)*60L*60L)/interval		;7 days plus 2 hours - have to go past end of week because need to see next
						;day transition
param = [tarr(6), tarr(5), tarr(4), 23, 58, 0, interval, num]
;outdir = '$ydb/scratch'
outdir = concat_dir(getenv('ydb'), 'ref_scratch')
;outdir = '/db_isass5/ydb/ref_scratch'              ; removed hard coded
;                                                   ; dir (isass5 db gone...)
;                                                   ; slf 5-dec-2002
;
print, 'MK_FEM_AOSLOS: ', param
run_dsnfil, param, path=outdir, file_out=aoslos_file, asca=asca
;
end
