pro mk_fem_file, timarr, clobber=clobber, dirout=dirout, asca=asca, $
      orbit_period=orbit_period
;
;+
;NAME:
;	mk_fem_file
;PURPOSE:
;	To create the FEM file so that MK_FEM_WRT can write into it
;INPUT:
;	timarr - The time of one of the s/c day's in the week
;		 It does not have to be the first s/c day
;OPTIONAL INPUT:
;	clobber
;	dirout
;HISTORY:
;	Written Feb-92 by M.Morrison
;	10-Mar-92 (MDM) - Changed orbit step size to 97 min (from 95 min)
;	Ver 1.1 17-Mar-92 (MDM) - Write out the data structure version #
;	Ver 2.0 26-Mar-92 (MDM) - changed FileID to be exactly the predicted
;				  first minute of sun
;	Ver 2.1 26-May-92 (MDM) - Changed MK_FEM_WRT to use orbit duration
;				  of 97.5 instead of 98.0
;	Ver 2.2 17-Jun-92 (MDM) - Simple mod to change new file protection to
;				  666 (RW for everyone)
;		 7-Apr-93 (MDM) - Added /ASCA option
;V3.0   21-Feb-94 (MDM) - Increased the resolution of the day/night boundary
;                         by incorporating a call to GET_SUNSET
;                         (increase is from 15 sec to 1 sec resolution)
;V3.2	14-Apr-94 (MDM) - Changed period between ASCA orbits to 96 minutes
;			  (from 97 minutes)
;			- Program version was being logged as 2.2
;V3.21	15-Apr-94 (MDM) - Allowed 16*7 instead of 15*7 orbits in a week
;			  for ASCA
;V3.3	16-Jan-95 (MDM) - Patch for roll over to new year case
;V4.0	23-Mar-95 (MDM) - Modified to add Wallops (see MK_FEM)
;			- Modified to get the version from MK_FEM
;V5.0    7-Apr-99 (SLF) - add ORBIT_PERIOD input keyword (allow orbit degradation)
;V6.0    8-Dec-02 (SLF) - increment Orb/file (to 16) if orbit_period < 96
;                         (happened in last few months for Yohkoh)
;-
;
progName = 'MK_FEM_FILE'
;progVerNo = 3.30*1000
mk_fem, progverno, /version
progverno = progverno*1000
;
if (keyword_set(asca)) then begin
    if (n_elements(dirout) eq 0) then dirout = '$DIR_ASCA_FEM'
end else begin
    if (n_elements(dirout) eq 0) then dirout = '$DIR_GEN_FEM'
end
;
qdebug = 1
timarr0 = timarr
timarr0(0:3) = [0,0,0,0]	;zero out the hours
ex2int, timarr0, time0, day0
ex2int, timarr, time, day
dow = ex2dow(timarr0)		& last_dow = dow
week = ex2week(timarr0)		& last_week = week
try = -1
step = orbit_period*60.*1000.		;the orbit duration  
time = time + step		;move forward since first thing done is to subract "step"
repeat begin			;back up the the time of the first  orbit

    try = try + 1
    time = time - step
    check_time, time, day

    int2ex, time, day, tarr
    dow = ex2dow(tarr)
    week = ex2week(tarr)
    dtim = dow*24.*60.*86400 + time/1000				;time in seconds from first s/c day for that week
									;time0 = 0 always

    if (qdebug) then print, try, dtim, fmt_tim(tarr), last_dow, dow, last_week, week

    qdone = 0
    if (dow gt last_dow) then begin		;rolled over to previous week - bad
	if (qdebug) then print, 'Rolled over to previous week - exiting'
	time = time + step			;move forward to the week in question
	check_time, time, day
	qdone = 1
    end
    if ((last_week eq 1) and (week gt 50) and (not qdone)) then begin		;rolled over to a new year (backing up)
	if (qdebug) then print, 'Rolled over to previous year - exiting'
	time = time + step			;move forward to the week in question
	check_time, time, day
	qdone = 1
    end

    last_week = week
    last_dow  = dow
end until qdone
;
int2ex, time, day, timarr
week = ex2week(timarr)
;
;filnam = 'fem' + string(timarr(6),'_', week, 'a.01', format='(i2.2,a,i2.2,a)') 
;filnam = 'fem' + string(timarr(6),'_', week, 'a.02', format='(i2.2,a,i2.2,a)') 
;filnam = 'fem' + string(timarr(6),'_', week, 'a.03', format='(i2.2,a,i2.2,a)') 
 filnam = 'fem' + string(timarr(6),'_', week, 'a.', fix(progverno/1000.), format='(i2.2,a,i2.2,a,i2.2)') 
outfil = concat_dir(dirout, filnam)
print, 'Making new file: ', outfil
;
rsiz = 16
get_lun, lun
open_da_file, lun, '', '', outfil, rsiz, bytout, fpoint, /nolower
gen_struct, file_header=fhead
;
fpoint.data_section     = bytout
;
fem_struct, fem_version=fem_version
fpoint.data_version	= fem_version.data
;
fem_struct, fem_data = fem_data
;
time2 = time
day2  = day
ndset = ( (orbit_period lt 96.) + 15)*7            ;SLF  8-Dec-02
if (keyword_set(asca)) then ndset = 16*7	;MDM 15-Apr-94
max_orbperfile=ndset/7
box_message,'Maximumb orbits/file= ' + strtrim(max_orbperfile,2)
for i=0,ndset-1 do begin
    fem_data.time = time2
    fem_data.day  = day2
    rdwrt, 'W', lun, bytout, rsiz, fem_data, 1
    ;
    time2 = time2 + 98*60.*1000.
    check_time, time2, day2
end
;
fpoint.TotBytes         = bytout

fhead.first_Time        = time
fhead.first_Day         = day
fhead.last_Time         = time2
fhead.last_Day          = day2

fhead.nDataSets         = ndset
fhead.maxSamps          = 0

file_id = ' '

if (keyword_set(asca)) then spacecraft='ASC'
wrt1p_fh, lun, fpoint, fhead, rsiz, progName, progVerNo, file_id, 'FEM', 'All', spacecraft=spacecraft
free_lun, lun
;
spawn, 'chmod 666 ' + outfil
end
