pro mk_fem_wrt, fem_data, clobber=clobber, dirout=dirout, asca=asca, $
     use_orbit_period=use_orbit_period
;
;
;HISTORY:
;	 7-Apr-93 (MDM) - Added /ASCA option
;V3.0	21-Feb-94 (MDM) - Increased the resolution of the night time to 1 second
;			  (from 15 sec)
;	14-Apr-94 (MDM) - Made period for asca to be 96 minutes.
;	19-May-94 (MDM) - Corrected 14-Apr-94 modification
;V4.0	23-Mar-95 (MDM) - Modified to add Wallops (see MK_FEM)
;			- Modified to get the version from MK_FEM
;
qdebug = 1
common mk_fem_wrt_blk, orbit_period, last_fem
;
mk_fem, progverno, /version
;
if n_elements(last_fem) eq 0 then begin
   last_fem=fem_data(0)
   last_fem.day=last_fem.day+100              ; force update 1st time
endif

if keyword_set(use_orbit_period) then begin 
   orbit_period=use_orbit_period
         box_message,'Using Input YOHKOH oribital period: ' + $ 
            string(orbit_period,format='(f5.2)')
endif else begin 
if n_elements(orbit_period) eq 0 or abs((ssw_deltat(fem_data(0),last_fem,/day))(0) gt 10) then begin 
   case 1 of 
      keyword_set(asca): orbit_period=96.
      else: begin 
         orbit_period=97.                      ; backwardly compatible
         rd_fem,reltime(fem_data(0),days=-10),reltime(fem_data(0),days=-1),fem
         if data_chk(fem,/struct) then  begin
            femdt=ssw_deltat(fem,/min)
            avgdt=average(femdt)
            femok=where(abs(femdt-avgdt) lt 5,okss)
            orbit_period=average(femdt(femok))
         endif
         box_message,'Using YOHKOH oribital period: ' + $ 
            string(orbit_period,format='(f5.2)')
        last_fem=fem_data(0)
      endcase
   endcase
endif
endelse

int2ex, fem_data.time, fem_data.day, timarr
;filnam = 'fem' + string(fem_data.year, '_', fem_data.week, 'a.03', format='(i2.2,a,i2.2,a)')
 filnam = 'fem' + string(fem_data.year, '_', fem_data.week, 'a.', fix(progverno), format='(i2.2,a,i2.2,a,i2.2)') 
outfil = concat_dir(dirout, filnam)
ff = findfile(outfil)
if (ff(0) eq '') then begin
    print, 'Need new file: ', outfil
    mk_fem_file, timarr, dirout=dirout, asca=asca, orbit_period=orbit_period
end
;
box_message,'Opening file>> ' + outfil 
openu, lun, outfil, /block, /get_lun
;
rd_pointer, lun, pointer
rd_fheader, lun, fheader
rsiz = pointer.VMS_rec_Size
;
day0 = fheader.first_day
time0 = fheader.first_time
;
dtim = (fem_data.day-day0)*86400. + (fem_data.time-time0)/1000.	;time in seconds from beginning of file

norbit = long(dtim/(orbit_period*60.)+.5)		;+.5 to round off
if (keyword_set(asca)) then norbit = long(dtim/(96.0*60.)+.5) 
;
bytout = pointer.data_section + norbit*get_nbytes(fem_data)
fem_struct, fem_data=fem_data0
rdwrt, 'R', lun, bytout, rsiz, fem_data0
qwrite = 0
if (fem_data0.night eq 0) then begin
    qwrite = 1
end else begin
    if (keyword_set(clobber)) then qwrite = 1
end
;
lstat=fstat(lun)
if not lstat.open then begin
   box_message,'lun Not Open!!'
   file_append,concat_dir('$SSW_SITE_LOGS','mk_fem_badlun.dat'), $
       [outfil,string(lun)]
   openu, lun, outfil, /block, /get_lun
endif
if (qwrite) then rdwrt, 'W', lun, bytout, rsiz, fem_data
;
if (qdebug) then print, norbit, ' -- ', fmt_tim(fem_data), '  ', fmt_tim(timarr), fem_data.path
;
free_lun, lun
end
